# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='api.proto',
  package='martin',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\tapi.proto\x12\x06martin\"q\n\x19\x46\x65tchFundingWalletRequest\x12\x11\n\tclient_id\x18\x01 \x01(\x03\x12\r\n\x05\x61sset\x18\x02 \x01(\t\x12\x1a\n\x12need_btc_valuation\x18\x03 \x01(\x08\x12\x16\n\x0ereceive_window\x18\x04 \x01(\x03\"\xd0\x01\n\x1a\x46\x65tchFundingWalletResponse\x12=\n\x08\x62\x61lances\x18\x01 \x03(\x0b\x32+.martin.FetchFundingWalletResponse.Balances\x1as\n\x08\x42\x61lances\x12\r\n\x05\x61sset\x18\x01 \x01(\t\x12\x0c\n\x04\x66ree\x18\x02 \x01(\t\x12\x0e\n\x06locked\x18\x03 \x01(\t\x12\x0e\n\x06\x66reeze\x18\x04 \x01(\t\x12\x13\n\x0bwithdrawing\x18\x05 \x01(\t\x12\x15\n\rbtc_valuation\x18\x06 \x01(\t\"\xa6\x02\n\x13\x43\x61ncelOrderResponse\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x19\n\x11origClientOrderId\x18\x02 \x01(\t\x12\x0f\n\x07orderId\x18\x03 \x01(\x04\x12\x13\n\x0borderListId\x18\x04 \x01(\x05\x12\x15\n\rclientOrderId\x18\x05 \x01(\t\x12\x14\n\x0ctransactTime\x18\x06 \x01(\x04\x12\r\n\x05price\x18\x07 \x01(\t\x12\x0f\n\x07origQty\x18\x08 \x01(\t\x12\x13\n\x0b\x65xecutedQty\x18\t \x01(\t\x12\x1b\n\x13\x63ummulativeQuoteQty\x18\n \x01(\t\x12\x0e\n\x06status\x18\x0b \x01(\t\x12\x13\n\x0btimeInForce\x18\x0c \x01(\t\x12\x0c\n\x04type\x18\r \x01(\t\x12\x0c\n\x04side\x18\x0e \x01(\t\"I\n\x12\x43\x61ncelOrderRequest\x12\x11\n\tclient_id\x18\x01 \x01(\x03\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12\x10\n\x08order_id\x18\x03 \x01(\x03\"\x90\x02\n\x18\x43reateLimitOrderResponse\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x0f\n\x07orderId\x18\x02 \x01(\x04\x12\x13\n\x0borderListId\x18\x03 \x01(\x11\x12\x15\n\rclientOrderId\x18\x04 \x01(\t\x12\x14\n\x0ctransactTime\x18\x05 \x01(\x04\x12\r\n\x05price\x18\x06 \x01(\t\x12\x0f\n\x07origQty\x18\x07 \x01(\t\x12\x13\n\x0b\x65xecutedQty\x18\x08 \x01(\t\x12\x1b\n\x13\x63ummulativeQuoteQty\x18\t \x01(\t\x12\x0e\n\x06status\x18\n \x01(\t\x12\x13\n\x0btimeInForce\x18\x0b \x01(\t\x12\x0c\n\x04type\x18\x0c \x01(\t\x12\x0c\n\x04side\x18\r \x01(\t\"\x8c\x01\n\x17\x43reateLimitOrderRequest\x12\x11\n\tclient_id\x18\x01 \x01(\x03\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12\x10\n\x08\x62uy_side\x18\x03 \x01(\x08\x12\x10\n\x08quantity\x18\x04 \x01(\t\x12\r\n\x05price\x18\x05 \x01(\t\x12\x1b\n\x13new_client_order_id\x18\x06 \x01(\x03\"\xf8\x05\n\x15OnOrderUpdateResponse\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x17\n\x0f\x63lient_order_id\x18\x02 \x01(\t\x12\x0c\n\x04side\x18\x03 \x01(\t\x12\x12\n\norder_type\x18\x04 \x01(\t\x12\x15\n\rtime_in_force\x18\x05 \x01(\t\x12\x16\n\x0eorder_quantity\x18\x06 \x01(\t\x12\x13\n\x0border_price\x18\x07 \x01(\t\x12\x12\n\nstop_price\x18\x08 \x01(\t\x12\x18\n\x10iceberg_quantity\x18\t \x01(\t\x12\x15\n\rorder_list_id\x18\n \x01(\x11\x12\x1a\n\x12original_client_id\x18\x0b \x01(\t\x12\x16\n\x0e\x65xecution_type\x18\x0c \x01(\t\x12\x14\n\x0corder_status\x18\r \x01(\t\x12\x1b\n\x13order_reject_reason\x18\x0e \x01(\t\x12\x10\n\x08order_id\x18\x0f \x01(\x04\x12\x1e\n\x16last_executed_quantity\x18\x10 \x01(\t\x12\"\n\x1a\x63umulative_filled_quantity\x18\x11 \x01(\t\x12\x1b\n\x13last_executed_price\x18\x12 \x01(\t\x12\x19\n\x11\x63ommission_amount\x18\x13 \x01(\t\x12\x18\n\x10\x63ommission_asset\x18\x14 \x01(\t\x12\x18\n\x10transaction_time\x18\x15 \x01(\x04\x12\x10\n\x08trade_id\x18\x16 \x01(\x12\x12\x10\n\x08ignore_a\x18\x17 \x01(\x04\x12\x15\n\rin_order_book\x18\x18 \x01(\x08\x12\x15\n\ris_maker_side\x18\x19 \x01(\x08\x12\x10\n\x08ignore_b\x18\x1a \x01(\x08\x12\x1b\n\x13order_creation_time\x18\x1b \x01(\x04\x12\x1e\n\x16quote_asset_transacted\x18\x1c \x01(\t\x12#\n\x1blast_quote_asset_transacted\x18\x1d \x01(\t\x12\x1c\n\x14quote_order_quantity\x18\x1e \x01(\t\"&\n\x15OnFundsUpdateResponse\x12\r\n\x05\x66unds\x18\x01 \x01(\t\"b\n\x14OnFundsUpdateRequest\x12\x11\n\tclient_id\x18\x01 \x01(\x03\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12\x12\n\nbase_asset\x18\x03 \x01(\t\x12\x13\n\x0bquote_asset\x18\x04 \x01(\t\"!\n\x0eSimpleResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"e\n\x16OnTickerUpdateResponse\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x12\n\nopen_price\x18\x02 \x01(\t\x12\x13\n\x0b\x63lose_price\x18\x03 \x01(\t\x12\x12\n\nevent_time\x18\x04 \x01(\x04\"\xbd\x02\n\x18\x41\x63\x63ountTradeListResponse\x12\x35\n\x05items\x18\x01 \x03(\x0b\x32&.martin.AccountTradeListResponse.Trade\x1a\xe9\x01\n\x05Trade\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x04\x12\x0f\n\x07orderId\x18\x03 \x01(\x04\x12\x13\n\x0borderListId\x18\x04 \x01(\x11\x12\r\n\x05price\x18\x05 \x01(\t\x12\x0b\n\x03qty\x18\x06 \x01(\t\x12\x10\n\x08quoteQty\x18\x07 \x01(\t\x12\x12\n\ncommission\x18\x08 \x01(\t\x12\x17\n\x0f\x63ommissionAsset\x18\t \x01(\t\x12\x0c\n\x04time\x18\n \x01(\x04\x12\x0f\n\x07isBuyer\x18\x0b \x01(\x08\x12\x0f\n\x07isMaker\x18\x0c \x01(\x08\x12\x13\n\x0bisBestMatch\x18\r \x01(\x08\"_\n\x17\x41\x63\x63ountTradeListRequest\x12\x11\n\tclient_id\x18\x01 \x01(\x03\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\r\x12\x12\n\nstart_time\x18\x04 \x01(\x03\"%\n\x13\x46\x65tchKlinesResponse\x12\x0e\n\x06klines\x18\x01 \x03(\t\"J\n\x16OnKlinesUpdateResponse\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x10\n\x08interval\x18\x02 \x01(\t\x12\x0e\n\x06\x63\x61ndle\x18\x03 \x01(\t\"X\n\x12\x46\x65tchKlinesRequest\x12\x11\n\tclient_id\x18\x01 \x01(\x03\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12\x10\n\x08interval\x18\x03 \x01(\t\x12\r\n\x05limit\x18\x04 \x01(\r\"\xb7\x03\n(FetchTickerPriceChangeStatisticsResponse\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x13\n\x0bpriceChange\x18\x02 \x01(\t\x12\x1a\n\x12priceChangePercent\x18\x03 \x01(\t\x12\x18\n\x10weightedAvgPrice\x18\x04 \x01(\t\x12\x16\n\x0eprevClosePrice\x18\x05 \x01(\t\x12\x11\n\tlastPrice\x18\x06 \x01(\t\x12\x0f\n\x07lastQty\x18\x07 \x01(\t\x12\x10\n\x08\x62idPrice\x18\x08 \x01(\t\x12\x0e\n\x06\x62idQty\x18\t \x01(\t\x12\x10\n\x08\x61skPrice\x18\n \x01(\t\x12\x0e\n\x06\x61skQty\x18\x0b \x01(\t\x12\x11\n\topenPrice\x18\x0c \x01(\t\x12\x11\n\thighPrice\x18\r \x01(\t\x12\x10\n\x08lowPrice\x18\x0e \x01(\t\x12\x0e\n\x06volume\x18\x0f \x01(\t\x12\x13\n\x0bquoteVolume\x18\x10 \x01(\t\x12\x10\n\x08openTime\x18\x11 \x01(\x04\x12\x11\n\tcloseTime\x18\x12 \x01(\x04\x12\x0f\n\x07\x66irstId\x18\x13 \x01(\x04\x12\x0e\n\x06lastId\x18\x14 \x01(\x04\x12\r\n\x05\x63ount\x18\x15 \x01(\x04\"?\n\x1e\x46\x65tchSymbolPriceTickerResponse\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\r\n\x05price\x18\x02 \x01(\t\"J\n\x16\x46\x65tchOrderBookResponse\x12\x14\n\x0clastUpdateId\x18\x01 \x01(\x04\x12\x0c\n\x04\x62ids\x18\x02 \x03(\t\x12\x0c\n\x04\x61sks\x18\x03 \x03(\t\"\x96\x01\n\x1b\x46\x65tchAccountBalanceResponse\x12>\n\x08\x62\x61lances\x18\x01 \x03(\x0b\x32,.martin.FetchAccountBalanceResponse.Balances\x1a\x37\n\x08\x42\x61lances\x12\r\n\x05\x61sset\x18\x01 \x01(\t\x12\x0c\n\x04\x66ree\x18\x02 \x01(\t\x12\x0e\n\x06locked\x18\x03 \x01(\t\"\xe9\x12\n\x1f\x46\x65tchExchangeInfoSymbolResponse\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x11\n\tbaseAsset\x18\x03 \x01(\t\x12\x1a\n\x12\x62\x61seAssetPrecision\x18\x04 \x01(\r\x12\x12\n\nquoteAsset\x18\x05 \x01(\t\x12\x16\n\x0equotePrecision\x18\x06 \x01(\r\x12\x1b\n\x13quoteAssetPrecision\x18\x07 \x01(\r\x12\x1f\n\x17\x62\x61seCommissionPrecision\x18\x08 \x01(\r\x12 \n\x18quoteCommissionPrecision\x18\t \x01(\r\x12\x12\n\norderTypes\x18\n \x03(\t\x12\x16\n\x0eicebergAllowed\x18\x0b \x01(\x08\x12\x12\n\nocoAllowed\x18\x0c \x01(\x08\x12\"\n\x1aquoteOrderQtyMarketAllowed\x18\r \x01(\x08\x12\x19\n\x11\x61llowTrailingStop\x18\x0e \x01(\x08\x12\x1c\n\x14isSpotTradingAllowed\x18\x0f \x01(\x08\x12\x1e\n\x16isMarginTradingAllowed\x18\x10 \x01(\x08\x12@\n\x07\x66ilters\x18\x11 \x01(\x0b\x32/.martin.FetchExchangeInfoSymbolResponse.Filters\x12\x13\n\x0bpermissions\x18\x12 \x03(\t\x1a\xd6\x0e\n\x07\x46ilters\x12V\n\x0cprice_filter\x18\x01 \x01(\x0b\x32;.martin.FetchExchangeInfoSymbolResponse.Filters.PriceFilterH\x00\x88\x01\x01\x12X\n\rpercent_price\x18\x02 \x01(\x0b\x32<.martin.FetchExchangeInfoSymbolResponse.Filters.PercentPriceH\x01\x88\x01\x01\x12N\n\x08lot_size\x18\x03 \x01(\x0b\x32\x37.martin.FetchExchangeInfoSymbolResponse.Filters.LotSizeH\x02\x88\x01\x01\x12V\n\x0cmin_notional\x18\x04 \x01(\x0b\x32;.martin.FetchExchangeInfoSymbolResponse.Filters.MinNotionalH\x03\x88\x01\x01\x12X\n\riceberg_parts\x18\x05 \x01(\x0b\x32<.martin.FetchExchangeInfoSymbolResponse.Filters.IcebergPartsH\x04\x88\x01\x01\x12[\n\x0fmarket_lot_size\x18\x06 \x01(\x0b\x32=.martin.FetchExchangeInfoSymbolResponse.Filters.MarketLotSizeH\x05\x88\x01\x01\x12Y\n\x0emax_num_orders\x18\x07 \x01(\x0b\x32<.martin.FetchExchangeInfoSymbolResponse.Filters.MaxNumOrdersH\x06\x88\x01\x01\x12\x62\n\x13max_num_algo_orders\x18\x08 \x01(\x0b\x32@.martin.FetchExchangeInfoSymbolResponse.Filters.MaxNumAlgoOrdersH\x07\x88\x01\x01\x12h\n\x16max_num_iceberg_orders\x18\t \x01(\x0b\x32\x43.martin.FetchExchangeInfoSymbolResponse.Filters.MaxNumIcebergOrdersH\x08\x88\x01\x01\x12V\n\x0cmax_position\x18\n \x01(\x0b\x32;.martin.FetchExchangeInfoSymbolResponse.Filters.MaxPositionH\t\x88\x01\x01\x1aW\n\x0bPriceFilter\x12\x12\n\nfilterType\x18\x01 \x01(\t\x12\x10\n\x08minPrice\x18\x02 \x01(\t\x12\x10\n\x08maxPrice\x18\x03 \x01(\t\x12\x10\n\x08tickSize\x18\x04 \x01(\t\x1a\x66\n\x0cPercentPrice\x12\x12\n\nfilterType\x18\x01 \x01(\t\x12\x14\n\x0cmultiplierUp\x18\x02 \x01(\t\x12\x16\n\x0emultiplierDown\x18\x03 \x01(\t\x12\x14\n\x0c\x61vgPriceMins\x18\x04 \x01(\r\x1aO\n\x07LotSize\x12\x12\n\nfilterType\x18\x01 \x01(\t\x12\x0e\n\x06minQty\x18\x02 \x01(\t\x12\x0e\n\x06maxQty\x18\x03 \x01(\t\x12\x10\n\x08stepSize\x18\x04 \x01(\t\x1a\x63\n\x0bMinNotional\x12\x12\n\nfilterType\x18\x01 \x01(\t\x12\x13\n\x0bminNotional\x18\x02 \x01(\t\x12\x15\n\rapplyToMarket\x18\x03 \x01(\x08\x12\x14\n\x0c\x61vgPriceMins\x18\x04 \x01(\r\x1a\x31\n\x0cIcebergParts\x12\x12\n\nfilterType\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\r\x1aU\n\rMarketLotSize\x12\x12\n\nfilterType\x18\x01 \x01(\t\x12\x0e\n\x06minQty\x18\x02 \x01(\t\x12\x0e\n\x06maxQty\x18\x03 \x01(\t\x12\x10\n\x08stepSize\x18\x04 \x01(\t\x1a\x38\n\x0cMaxNumOrders\x12\x12\n\nfilterType\x18\x01 \x01(\t\x12\x14\n\x0cmaxNumOrders\x18\x02 \x01(\r\x1a@\n\x10MaxNumAlgoOrders\x12\x12\n\nfilterType\x18\x01 \x01(\t\x12\x18\n\x10maxNumAlgoOrders\x18\x02 \x01(\r\x1a\x46\n\x13MaxNumIcebergOrders\x12\x12\n\nfilterType\x18\x01 \x01(\t\x12\x1b\n\x13maxNumIcebergOrders\x18\x02 \x01(\r\x1a\x36\n\x0bMaxPosition\x12\x12\n\nfilterType\x18\x01 \x01(\t\x12\x13\n\x0bmaxPosition\x18\x02 \x01(\tB\x0f\n\r_price_filterB\x10\n\x0e_percent_priceB\x0b\n\t_lot_sizeB\x0f\n\r_min_notionalB\x10\n\x0e_iceberg_partsB\x12\n\x10_market_lot_sizeB\x11\n\x0f_max_num_ordersB\x16\n\x14_max_num_algo_ordersB\x19\n\x17_max_num_iceberg_ordersB\x0f\n\r_max_position\"\xf6\x02\n\x17\x43\x61ncelAllOrdersResponse\x12:\n\x05items\x18\x01 \x03(\x0b\x32+.martin.CancelAllOrdersResponse.CancelOrder\x1a\x9e\x02\n\x0b\x43\x61ncelOrder\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x19\n\x11origClientOrderId\x18\x02 \x01(\t\x12\x0f\n\x07orderId\x18\x03 \x01(\x04\x12\x13\n\x0borderListId\x18\x04 \x01(\x05\x12\x15\n\rclientOrderId\x18\x05 \x01(\t\x12\x14\n\x0ctransactTime\x18\x06 \x01(\x04\x12\r\n\x05price\x18\x07 \x01(\t\x12\x0f\n\x07origQty\x18\x08 \x01(\t\x12\x13\n\x0b\x65xecutedQty\x18\t \x01(\t\x12\x1b\n\x13\x63ummulativeQuoteQty\x18\n \x01(\t\x12\x0e\n\x06status\x18\x0b \x01(\t\x12\x13\n\x0btimeInForce\x18\x0c \x01(\t\x12\x0c\n\x04type\x18\r \x01(\t\x12\x0c\n\x04side\x18\x0e \x01(\t\"d\n\x11\x46\x65tchOrderRequest\x12\x11\n\tclient_id\x18\x01 \x01(\x03\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12\x10\n\x08order_id\x18\x03 \x01(\x03\x12\x1a\n\x12\x66illed_update_call\x18\x04 \x01(\x08\"\xeb\x02\n\x12\x46\x65tchOrderResponse\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x0f\n\x07orderId\x18\x02 \x01(\x04\x12\x13\n\x0borderListId\x18\x03 \x01(\x11\x12\x15\n\rclientOrderId\x18\x04 \x01(\t\x12\r\n\x05price\x18\x05 \x01(\t\x12\x0f\n\x07origQty\x18\x06 \x01(\t\x12\x13\n\x0b\x65xecutedQty\x18\x07 \x01(\t\x12\x1b\n\x13\x63ummulativeQuoteQty\x18\x08 \x01(\t\x12\x0e\n\x06status\x18\t \x01(\t\x12\x13\n\x0btimeInForce\x18\n \x01(\t\x12\x0c\n\x04type\x18\x0b \x01(\t\x12\x0c\n\x04side\x18\x0c \x01(\t\x12\x11\n\tstopPrice\x18\r \x01(\t\x12\x12\n\nicebergQty\x18\x0e \x01(\t\x12\x0c\n\x04time\x18\x0f \x01(\x04\x12\x12\n\nupdateTime\x18\x10 \x01(\x04\x12\x11\n\tisWorking\x18\x11 \x01(\x08\x12\x19\n\x11origQuoteOrderQty\x18\x12 \x01(\t\"\xc6\x03\n\x17\x46\x65tchOpenOrdersResponse\x12\x14\n\x0crate_limiter\x18\x01 \x01(\x05\x12\x34\n\x05items\x18\x02 \x03(\x0b\x32%.martin.FetchOpenOrdersResponse.Order\x1a\xde\x02\n\x05Order\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x0f\n\x07orderId\x18\x02 \x01(\x04\x12\x13\n\x0borderListId\x18\x03 \x01(\x11\x12\x15\n\rclientOrderId\x18\x04 \x01(\t\x12\r\n\x05price\x18\x05 \x01(\t\x12\x0f\n\x07origQty\x18\x06 \x01(\t\x12\x13\n\x0b\x65xecutedQty\x18\x07 \x01(\t\x12\x1b\n\x13\x63ummulativeQuoteQty\x18\x08 \x01(\t\x12\x0e\n\x06status\x18\t \x01(\t\x12\x13\n\x0btimeInForce\x18\n \x01(\t\x12\x0c\n\x04type\x18\x0b \x01(\t\x12\x0c\n\x04side\x18\x0c \x01(\t\x12\x11\n\tstopPrice\x18\r \x01(\t\x12\x12\n\nicebergQty\x18\x0e \x01(\t\x12\x0c\n\x04time\x18\x0f \x01(\x04\x12\x12\n\nupdateTime\x18\x10 \x01(\x04\x12\x11\n\tisWorking\x18\x11 \x01(\x08\x12\x19\n\x11origQuoteOrderQty\x18\x12 \x01(\t\"2\n\rMarketRequest\x12\x11\n\tclient_id\x18\x01 \x01(\x03\x12\x0e\n\x06symbol\x18\x02 \x01(\t\"o\n\x12StartStreamRequest\x12\x11\n\tclient_id\x18\x01 \x01(\x03\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12\x1b\n\x13market_stream_count\x18\x03 \x01(\x05\x12\x19\n\x11user_stream_count\x18\x04 \x01(\x05\"I\n\x1bOpenClientConnectionRequest\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x01 \x01(\t\x12\x14\n\x0crate_limiter\x18\x02 \x01(\x05\"V\n\x16OpenClientConnectionId\x12\x11\n\tclient_id\x18\x01 \x01(\x03\x12\x13\n\x0bsrv_version\x18\x02 \x01(\t\x12\x14\n\x0crate_limiter\x18\x03 \x01(\x05\"+\n\x16\x46\x65tchServerTimeRequest\x12\x11\n\tclient_id\x18\x01 \x01(\x03\".\n\x17\x46\x65tchServerTimeResponse\x12\x13\n\x0bserver_time\x18\x01 \x01(\x04\x32\xf8\x0e\n\x06Martin\x12]\n\x14OpenClientConnection\x12#.martin.OpenClientConnectionRequest\x1a\x1e.martin.OpenClientConnectionId\"\x00\x12T\n\x0f\x46\x65tchServerTime\x12\x1e.martin.OpenClientConnectionId\x1a\x1f.martin.FetchServerTimeResponse\"\x00\x12K\n\x0f\x46\x65tchOpenOrders\x12\x15.martin.MarketRequest\x1a\x1f.martin.FetchOpenOrdersResponse\"\x00\x12K\n\x0f\x43\x61ncelAllOrders\x12\x15.martin.MarketRequest\x1a\x1f.martin.FetchOpenOrdersResponse\"\x00\x12[\n\x17\x46\x65tchExchangeInfoSymbol\x12\x15.martin.MarketRequest\x1a\'.martin.FetchExchangeInfoSymbolResponse\"\x00\x12`\n\x17\x46\x65tchAccountInformation\x12\x1e.martin.OpenClientConnectionId\x1a#.martin.FetchAccountBalanceResponse\"\x00\x12I\n\x0e\x46\x65tchOrderBook\x12\x15.martin.MarketRequest\x1a\x1e.martin.FetchOrderBookResponse\"\x00\x12Y\n\x16\x46\x65tchSymbolPriceTicker\x12\x15.martin.MarketRequest\x1a&.martin.FetchSymbolPriceTickerResponse\"\x00\x12m\n FetchTickerPriceChangeStatistics\x12\x15.martin.MarketRequest\x1a\x30.martin.FetchTickerPriceChangeStatisticsResponse\"\x00\x12H\n\x0b\x46\x65tchKlines\x12\x1a.martin.FetchKlinesRequest\x1a\x1b.martin.FetchKlinesResponse\"\x00\x12\\\n\x15\x46\x65tchAccountTradeList\x12\x1f.martin.AccountTradeListRequest\x1a .martin.AccountTradeListResponse\"\x00\x12K\n\x0eOnTickerUpdate\x12\x15.martin.MarketRequest\x1a\x1e.martin.OnTickerUpdateResponse\"\x00\x30\x01\x12N\n\x11OnOrderBookUpdate\x12\x15.martin.MarketRequest\x1a\x1e.martin.FetchOrderBookResponse\"\x00\x30\x01\x12=\n\nStopStream\x12\x15.martin.MarketRequest\x1a\x16.martin.SimpleResponse\"\x00\x12\x43\n\x0bStartStream\x12\x1a.martin.StartStreamRequest\x1a\x16.martin.SimpleResponse\"\x00\x12P\n\rOnFundsUpdate\x12\x1c.martin.OnFundsUpdateRequest\x1a\x1d.martin.OnFundsUpdateResponse\"\x00\x30\x01\x12I\n\rOnOrderUpdate\x12\x15.martin.MarketRequest\x1a\x1d.martin.OnOrderUpdateResponse\"\x00\x30\x01\x12W\n\x10\x43reateLimitOrder\x12\x1f.martin.CreateLimitOrderRequest\x1a .martin.CreateLimitOrderResponse\"\x00\x12H\n\x0b\x43\x61ncelOrder\x12\x1a.martin.CancelOrderRequest\x1a\x1b.martin.CancelOrderResponse\"\x00\x12\x45\n\nFetchOrder\x12\x19.martin.FetchOrderRequest\x1a\x1a.martin.FetchOrderResponse\"\x00\x12J\n\x0eResetRateLimit\x12\x1e.martin.OpenClientConnectionId\x1a\x16.martin.SimpleResponse\"\x00\x12P\n\x0eOnKlinesUpdate\x12\x1a.martin.FetchKlinesRequest\x1a\x1e.martin.OnKlinesUpdateResponse\"\x00\x30\x01\x12]\n\x12\x46\x65tchFundingWallet\x12!.martin.FetchFundingWalletRequest\x1a\".martin.FetchFundingWalletResponse\"\x00\x62\x06proto3'
)




_FETCHFUNDINGWALLETREQUEST = _descriptor.Descriptor(
  name='FetchFundingWalletRequest',
  full_name='martin.FetchFundingWalletRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='martin.FetchFundingWalletRequest.client_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='asset', full_name='martin.FetchFundingWalletRequest.asset', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='need_btc_valuation', full_name='martin.FetchFundingWalletRequest.need_btc_valuation', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receive_window', full_name='martin.FetchFundingWalletRequest.receive_window', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21,
  serialized_end=134,
)


_FETCHFUNDINGWALLETRESPONSE_BALANCES = _descriptor.Descriptor(
  name='Balances',
  full_name='martin.FetchFundingWalletResponse.Balances',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='asset', full_name='martin.FetchFundingWalletResponse.Balances.asset', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='free', full_name='martin.FetchFundingWalletResponse.Balances.free', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locked', full_name='martin.FetchFundingWalletResponse.Balances.locked', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='freeze', full_name='martin.FetchFundingWalletResponse.Balances.freeze', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='withdrawing', full_name='martin.FetchFundingWalletResponse.Balances.withdrawing', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='btc_valuation', full_name='martin.FetchFundingWalletResponse.Balances.btc_valuation', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=230,
  serialized_end=345,
)

_FETCHFUNDINGWALLETRESPONSE = _descriptor.Descriptor(
  name='FetchFundingWalletResponse',
  full_name='martin.FetchFundingWalletResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='balances', full_name='martin.FetchFundingWalletResponse.balances', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FETCHFUNDINGWALLETRESPONSE_BALANCES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=137,
  serialized_end=345,
)


_CANCELORDERRESPONSE = _descriptor.Descriptor(
  name='CancelOrderResponse',
  full_name='martin.CancelOrderResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='martin.CancelOrderResponse.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origClientOrderId', full_name='martin.CancelOrderResponse.origClientOrderId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orderId', full_name='martin.CancelOrderResponse.orderId', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orderListId', full_name='martin.CancelOrderResponse.orderListId', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clientOrderId', full_name='martin.CancelOrderResponse.clientOrderId', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transactTime', full_name='martin.CancelOrderResponse.transactTime', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='martin.CancelOrderResponse.price', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origQty', full_name='martin.CancelOrderResponse.origQty', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='executedQty', full_name='martin.CancelOrderResponse.executedQty', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cummulativeQuoteQty', full_name='martin.CancelOrderResponse.cummulativeQuoteQty', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='martin.CancelOrderResponse.status', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeInForce', full_name='martin.CancelOrderResponse.timeInForce', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='martin.CancelOrderResponse.type', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='side', full_name='martin.CancelOrderResponse.side', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=348,
  serialized_end=642,
)


_CANCELORDERREQUEST = _descriptor.Descriptor(
  name='CancelOrderRequest',
  full_name='martin.CancelOrderRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='martin.CancelOrderRequest.client_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='martin.CancelOrderRequest.symbol', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_id', full_name='martin.CancelOrderRequest.order_id', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=644,
  serialized_end=717,
)


_CREATELIMITORDERRESPONSE = _descriptor.Descriptor(
  name='CreateLimitOrderResponse',
  full_name='martin.CreateLimitOrderResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='martin.CreateLimitOrderResponse.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orderId', full_name='martin.CreateLimitOrderResponse.orderId', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orderListId', full_name='martin.CreateLimitOrderResponse.orderListId', index=2,
      number=3, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clientOrderId', full_name='martin.CreateLimitOrderResponse.clientOrderId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transactTime', full_name='martin.CreateLimitOrderResponse.transactTime', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='martin.CreateLimitOrderResponse.price', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origQty', full_name='martin.CreateLimitOrderResponse.origQty', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='executedQty', full_name='martin.CreateLimitOrderResponse.executedQty', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cummulativeQuoteQty', full_name='martin.CreateLimitOrderResponse.cummulativeQuoteQty', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='martin.CreateLimitOrderResponse.status', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeInForce', full_name='martin.CreateLimitOrderResponse.timeInForce', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='martin.CreateLimitOrderResponse.type', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='side', full_name='martin.CreateLimitOrderResponse.side', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=720,
  serialized_end=992,
)


_CREATELIMITORDERREQUEST = _descriptor.Descriptor(
  name='CreateLimitOrderRequest',
  full_name='martin.CreateLimitOrderRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='martin.CreateLimitOrderRequest.client_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='martin.CreateLimitOrderRequest.symbol', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buy_side', full_name='martin.CreateLimitOrderRequest.buy_side', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='martin.CreateLimitOrderRequest.quantity', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='martin.CreateLimitOrderRequest.price', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_client_order_id', full_name='martin.CreateLimitOrderRequest.new_client_order_id', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=995,
  serialized_end=1135,
)


_ONORDERUPDATERESPONSE = _descriptor.Descriptor(
  name='OnOrderUpdateResponse',
  full_name='martin.OnOrderUpdateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='martin.OnOrderUpdateResponse.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_order_id', full_name='martin.OnOrderUpdateResponse.client_order_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='side', full_name='martin.OnOrderUpdateResponse.side', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_type', full_name='martin.OnOrderUpdateResponse.order_type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_in_force', full_name='martin.OnOrderUpdateResponse.time_in_force', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_quantity', full_name='martin.OnOrderUpdateResponse.order_quantity', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_price', full_name='martin.OnOrderUpdateResponse.order_price', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_price', full_name='martin.OnOrderUpdateResponse.stop_price', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='iceberg_quantity', full_name='martin.OnOrderUpdateResponse.iceberg_quantity', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_list_id', full_name='martin.OnOrderUpdateResponse.order_list_id', index=9,
      number=10, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='original_client_id', full_name='martin.OnOrderUpdateResponse.original_client_id', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_type', full_name='martin.OnOrderUpdateResponse.execution_type', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_status', full_name='martin.OnOrderUpdateResponse.order_status', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_reject_reason', full_name='martin.OnOrderUpdateResponse.order_reject_reason', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_id', full_name='martin.OnOrderUpdateResponse.order_id', index=14,
      number=15, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_executed_quantity', full_name='martin.OnOrderUpdateResponse.last_executed_quantity', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cumulative_filled_quantity', full_name='martin.OnOrderUpdateResponse.cumulative_filled_quantity', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_executed_price', full_name='martin.OnOrderUpdateResponse.last_executed_price', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commission_amount', full_name='martin.OnOrderUpdateResponse.commission_amount', index=18,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commission_asset', full_name='martin.OnOrderUpdateResponse.commission_asset', index=19,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transaction_time', full_name='martin.OnOrderUpdateResponse.transaction_time', index=20,
      number=21, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trade_id', full_name='martin.OnOrderUpdateResponse.trade_id', index=21,
      number=22, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ignore_a', full_name='martin.OnOrderUpdateResponse.ignore_a', index=22,
      number=23, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='in_order_book', full_name='martin.OnOrderUpdateResponse.in_order_book', index=23,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_maker_side', full_name='martin.OnOrderUpdateResponse.is_maker_side', index=24,
      number=25, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ignore_b', full_name='martin.OnOrderUpdateResponse.ignore_b', index=25,
      number=26, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_creation_time', full_name='martin.OnOrderUpdateResponse.order_creation_time', index=26,
      number=27, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_asset_transacted', full_name='martin.OnOrderUpdateResponse.quote_asset_transacted', index=27,
      number=28, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_quote_asset_transacted', full_name='martin.OnOrderUpdateResponse.last_quote_asset_transacted', index=28,
      number=29, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_order_quantity', full_name='martin.OnOrderUpdateResponse.quote_order_quantity', index=29,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1138,
  serialized_end=1898,
)


_ONFUNDSUPDATERESPONSE = _descriptor.Descriptor(
  name='OnFundsUpdateResponse',
  full_name='martin.OnFundsUpdateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='funds', full_name='martin.OnFundsUpdateResponse.funds', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1900,
  serialized_end=1938,
)


_ONFUNDSUPDATEREQUEST = _descriptor.Descriptor(
  name='OnFundsUpdateRequest',
  full_name='martin.OnFundsUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='martin.OnFundsUpdateRequest.client_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='martin.OnFundsUpdateRequest.symbol', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_asset', full_name='martin.OnFundsUpdateRequest.base_asset', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_asset', full_name='martin.OnFundsUpdateRequest.quote_asset', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1940,
  serialized_end=2038,
)


_SIMPLERESPONSE = _descriptor.Descriptor(
  name='SimpleResponse',
  full_name='martin.SimpleResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='martin.SimpleResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2040,
  serialized_end=2073,
)


_ONTICKERUPDATERESPONSE = _descriptor.Descriptor(
  name='OnTickerUpdateResponse',
  full_name='martin.OnTickerUpdateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='martin.OnTickerUpdateResponse.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open_price', full_name='martin.OnTickerUpdateResponse.open_price', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='close_price', full_name='martin.OnTickerUpdateResponse.close_price', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_time', full_name='martin.OnTickerUpdateResponse.event_time', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2075,
  serialized_end=2176,
)


_ACCOUNTTRADELISTRESPONSE_TRADE = _descriptor.Descriptor(
  name='Trade',
  full_name='martin.AccountTradeListResponse.Trade',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='martin.AccountTradeListResponse.Trade.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='martin.AccountTradeListResponse.Trade.id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orderId', full_name='martin.AccountTradeListResponse.Trade.orderId', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orderListId', full_name='martin.AccountTradeListResponse.Trade.orderListId', index=3,
      number=4, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='martin.AccountTradeListResponse.Trade.price', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qty', full_name='martin.AccountTradeListResponse.Trade.qty', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quoteQty', full_name='martin.AccountTradeListResponse.Trade.quoteQty', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commission', full_name='martin.AccountTradeListResponse.Trade.commission', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commissionAsset', full_name='martin.AccountTradeListResponse.Trade.commissionAsset', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='martin.AccountTradeListResponse.Trade.time', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isBuyer', full_name='martin.AccountTradeListResponse.Trade.isBuyer', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isMaker', full_name='martin.AccountTradeListResponse.Trade.isMaker', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isBestMatch', full_name='martin.AccountTradeListResponse.Trade.isBestMatch', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2263,
  serialized_end=2496,
)

_ACCOUNTTRADELISTRESPONSE = _descriptor.Descriptor(
  name='AccountTradeListResponse',
  full_name='martin.AccountTradeListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='martin.AccountTradeListResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ACCOUNTTRADELISTRESPONSE_TRADE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2179,
  serialized_end=2496,
)


_ACCOUNTTRADELISTREQUEST = _descriptor.Descriptor(
  name='AccountTradeListRequest',
  full_name='martin.AccountTradeListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='martin.AccountTradeListRequest.client_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='martin.AccountTradeListRequest.symbol', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='martin.AccountTradeListRequest.limit', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='martin.AccountTradeListRequest.start_time', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2498,
  serialized_end=2593,
)


_FETCHKLINESRESPONSE = _descriptor.Descriptor(
  name='FetchKlinesResponse',
  full_name='martin.FetchKlinesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='klines', full_name='martin.FetchKlinesResponse.klines', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2595,
  serialized_end=2632,
)


_ONKLINESUPDATERESPONSE = _descriptor.Descriptor(
  name='OnKlinesUpdateResponse',
  full_name='martin.OnKlinesUpdateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='martin.OnKlinesUpdateResponse.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interval', full_name='martin.OnKlinesUpdateResponse.interval', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='candle', full_name='martin.OnKlinesUpdateResponse.candle', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2634,
  serialized_end=2708,
)


_FETCHKLINESREQUEST = _descriptor.Descriptor(
  name='FetchKlinesRequest',
  full_name='martin.FetchKlinesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='martin.FetchKlinesRequest.client_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='martin.FetchKlinesRequest.symbol', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interval', full_name='martin.FetchKlinesRequest.interval', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='martin.FetchKlinesRequest.limit', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2710,
  serialized_end=2798,
)


_FETCHTICKERPRICECHANGESTATISTICSRESPONSE = _descriptor.Descriptor(
  name='FetchTickerPriceChangeStatisticsResponse',
  full_name='martin.FetchTickerPriceChangeStatisticsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='martin.FetchTickerPriceChangeStatisticsResponse.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priceChange', full_name='martin.FetchTickerPriceChangeStatisticsResponse.priceChange', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priceChangePercent', full_name='martin.FetchTickerPriceChangeStatisticsResponse.priceChangePercent', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weightedAvgPrice', full_name='martin.FetchTickerPriceChangeStatisticsResponse.weightedAvgPrice', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prevClosePrice', full_name='martin.FetchTickerPriceChangeStatisticsResponse.prevClosePrice', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastPrice', full_name='martin.FetchTickerPriceChangeStatisticsResponse.lastPrice', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastQty', full_name='martin.FetchTickerPriceChangeStatisticsResponse.lastQty', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bidPrice', full_name='martin.FetchTickerPriceChangeStatisticsResponse.bidPrice', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bidQty', full_name='martin.FetchTickerPriceChangeStatisticsResponse.bidQty', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='askPrice', full_name='martin.FetchTickerPriceChangeStatisticsResponse.askPrice', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='askQty', full_name='martin.FetchTickerPriceChangeStatisticsResponse.askQty', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='openPrice', full_name='martin.FetchTickerPriceChangeStatisticsResponse.openPrice', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='highPrice', full_name='martin.FetchTickerPriceChangeStatisticsResponse.highPrice', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lowPrice', full_name='martin.FetchTickerPriceChangeStatisticsResponse.lowPrice', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='martin.FetchTickerPriceChangeStatisticsResponse.volume', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quoteVolume', full_name='martin.FetchTickerPriceChangeStatisticsResponse.quoteVolume', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='openTime', full_name='martin.FetchTickerPriceChangeStatisticsResponse.openTime', index=16,
      number=17, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='closeTime', full_name='martin.FetchTickerPriceChangeStatisticsResponse.closeTime', index=17,
      number=18, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='firstId', full_name='martin.FetchTickerPriceChangeStatisticsResponse.firstId', index=18,
      number=19, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastId', full_name='martin.FetchTickerPriceChangeStatisticsResponse.lastId', index=19,
      number=20, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='martin.FetchTickerPriceChangeStatisticsResponse.count', index=20,
      number=21, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2801,
  serialized_end=3240,
)


_FETCHSYMBOLPRICETICKERRESPONSE = _descriptor.Descriptor(
  name='FetchSymbolPriceTickerResponse',
  full_name='martin.FetchSymbolPriceTickerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='martin.FetchSymbolPriceTickerResponse.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='martin.FetchSymbolPriceTickerResponse.price', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3242,
  serialized_end=3305,
)


_FETCHORDERBOOKRESPONSE = _descriptor.Descriptor(
  name='FetchOrderBookResponse',
  full_name='martin.FetchOrderBookResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lastUpdateId', full_name='martin.FetchOrderBookResponse.lastUpdateId', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bids', full_name='martin.FetchOrderBookResponse.bids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='asks', full_name='martin.FetchOrderBookResponse.asks', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3307,
  serialized_end=3381,
)


_FETCHACCOUNTBALANCERESPONSE_BALANCES = _descriptor.Descriptor(
  name='Balances',
  full_name='martin.FetchAccountBalanceResponse.Balances',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='asset', full_name='martin.FetchAccountBalanceResponse.Balances.asset', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='free', full_name='martin.FetchAccountBalanceResponse.Balances.free', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locked', full_name='martin.FetchAccountBalanceResponse.Balances.locked', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=230,
  serialized_end=285,
)

_FETCHACCOUNTBALANCERESPONSE = _descriptor.Descriptor(
  name='FetchAccountBalanceResponse',
  full_name='martin.FetchAccountBalanceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='balances', full_name='martin.FetchAccountBalanceResponse.balances', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FETCHACCOUNTBALANCERESPONSE_BALANCES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3384,
  serialized_end=3534,
)


_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_PRICEFILTER = _descriptor.Descriptor(
  name='PriceFilter',
  full_name='martin.FetchExchangeInfoSymbolResponse.Filters.PriceFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filterType', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.PriceFilter.filterType', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minPrice', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.PriceFilter.minPrice', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maxPrice', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.PriceFilter.maxPrice', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tickSize', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.PriceFilter.tickSize', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4993,
  serialized_end=5080,
)

_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_PERCENTPRICE = _descriptor.Descriptor(
  name='PercentPrice',
  full_name='martin.FetchExchangeInfoSymbolResponse.Filters.PercentPrice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filterType', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.PercentPrice.filterType', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='multiplierUp', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.PercentPrice.multiplierUp', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='multiplierDown', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.PercentPrice.multiplierDown', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avgPriceMins', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.PercentPrice.avgPriceMins', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5082,
  serialized_end=5184,
)

_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_LOTSIZE = _descriptor.Descriptor(
  name='LotSize',
  full_name='martin.FetchExchangeInfoSymbolResponse.Filters.LotSize',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filterType', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.LotSize.filterType', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minQty', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.LotSize.minQty', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maxQty', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.LotSize.maxQty', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stepSize', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.LotSize.stepSize', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5186,
  serialized_end=5265,
)

_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_MINNOTIONAL = _descriptor.Descriptor(
  name='MinNotional',
  full_name='martin.FetchExchangeInfoSymbolResponse.Filters.MinNotional',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filterType', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.MinNotional.filterType', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minNotional', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.MinNotional.minNotional', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='applyToMarket', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.MinNotional.applyToMarket', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avgPriceMins', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.MinNotional.avgPriceMins', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5267,
  serialized_end=5366,
)

_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_ICEBERGPARTS = _descriptor.Descriptor(
  name='IcebergParts',
  full_name='martin.FetchExchangeInfoSymbolResponse.Filters.IcebergParts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filterType', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.IcebergParts.filterType', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.IcebergParts.limit', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5368,
  serialized_end=5417,
)

_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_MARKETLOTSIZE = _descriptor.Descriptor(
  name='MarketLotSize',
  full_name='martin.FetchExchangeInfoSymbolResponse.Filters.MarketLotSize',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filterType', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.MarketLotSize.filterType', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minQty', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.MarketLotSize.minQty', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maxQty', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.MarketLotSize.maxQty', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stepSize', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.MarketLotSize.stepSize', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5419,
  serialized_end=5504,
)

_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_MAXNUMORDERS = _descriptor.Descriptor(
  name='MaxNumOrders',
  full_name='martin.FetchExchangeInfoSymbolResponse.Filters.MaxNumOrders',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filterType', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.MaxNumOrders.filterType', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maxNumOrders', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.MaxNumOrders.maxNumOrders', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5506,
  serialized_end=5562,
)

_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_MAXNUMALGOORDERS = _descriptor.Descriptor(
  name='MaxNumAlgoOrders',
  full_name='martin.FetchExchangeInfoSymbolResponse.Filters.MaxNumAlgoOrders',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filterType', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.MaxNumAlgoOrders.filterType', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maxNumAlgoOrders', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.MaxNumAlgoOrders.maxNumAlgoOrders', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5564,
  serialized_end=5628,
)

_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_MAXNUMICEBERGORDERS = _descriptor.Descriptor(
  name='MaxNumIcebergOrders',
  full_name='martin.FetchExchangeInfoSymbolResponse.Filters.MaxNumIcebergOrders',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filterType', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.MaxNumIcebergOrders.filterType', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maxNumIcebergOrders', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.MaxNumIcebergOrders.maxNumIcebergOrders', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5630,
  serialized_end=5700,
)

_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_MAXPOSITION = _descriptor.Descriptor(
  name='MaxPosition',
  full_name='martin.FetchExchangeInfoSymbolResponse.Filters.MaxPosition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filterType', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.MaxPosition.filterType', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maxPosition', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.MaxPosition.maxPosition', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5702,
  serialized_end=5756,
)

_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS = _descriptor.Descriptor(
  name='Filters',
  full_name='martin.FetchExchangeInfoSymbolResponse.Filters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='price_filter', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.price_filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percent_price', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.percent_price', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lot_size', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.lot_size', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_notional', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.min_notional', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='iceberg_parts', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.iceberg_parts', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_lot_size', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.market_lot_size', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_num_orders', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.max_num_orders', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_num_algo_orders', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.max_num_algo_orders', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_num_iceberg_orders', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.max_num_iceberg_orders', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_position', full_name='martin.FetchExchangeInfoSymbolResponse.Filters.max_position', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_PRICEFILTER, _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_PERCENTPRICE, _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_LOTSIZE, _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_MINNOTIONAL, _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_ICEBERGPARTS, _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_MARKETLOTSIZE, _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_MAXNUMORDERS, _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_MAXNUMALGOORDERS, _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_MAXNUMICEBERGORDERS, _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_MAXPOSITION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_price_filter', full_name='martin.FetchExchangeInfoSymbolResponse.Filters._price_filter',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_percent_price', full_name='martin.FetchExchangeInfoSymbolResponse.Filters._percent_price',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_lot_size', full_name='martin.FetchExchangeInfoSymbolResponse.Filters._lot_size',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_min_notional', full_name='martin.FetchExchangeInfoSymbolResponse.Filters._min_notional',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_iceberg_parts', full_name='martin.FetchExchangeInfoSymbolResponse.Filters._iceberg_parts',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_market_lot_size', full_name='martin.FetchExchangeInfoSymbolResponse.Filters._market_lot_size',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_max_num_orders', full_name='martin.FetchExchangeInfoSymbolResponse.Filters._max_num_orders',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_max_num_algo_orders', full_name='martin.FetchExchangeInfoSymbolResponse.Filters._max_num_algo_orders',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_max_num_iceberg_orders', full_name='martin.FetchExchangeInfoSymbolResponse.Filters._max_num_iceberg_orders',
      index=8, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_max_position', full_name='martin.FetchExchangeInfoSymbolResponse.Filters._max_position',
      index=9, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4068,
  serialized_end=5946,
)

_FETCHEXCHANGEINFOSYMBOLRESPONSE = _descriptor.Descriptor(
  name='FetchExchangeInfoSymbolResponse',
  full_name='martin.FetchExchangeInfoSymbolResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='martin.FetchExchangeInfoSymbolResponse.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='martin.FetchExchangeInfoSymbolResponse.status', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baseAsset', full_name='martin.FetchExchangeInfoSymbolResponse.baseAsset', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baseAssetPrecision', full_name='martin.FetchExchangeInfoSymbolResponse.baseAssetPrecision', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quoteAsset', full_name='martin.FetchExchangeInfoSymbolResponse.quoteAsset', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quotePrecision', full_name='martin.FetchExchangeInfoSymbolResponse.quotePrecision', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quoteAssetPrecision', full_name='martin.FetchExchangeInfoSymbolResponse.quoteAssetPrecision', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baseCommissionPrecision', full_name='martin.FetchExchangeInfoSymbolResponse.baseCommissionPrecision', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quoteCommissionPrecision', full_name='martin.FetchExchangeInfoSymbolResponse.quoteCommissionPrecision', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orderTypes', full_name='martin.FetchExchangeInfoSymbolResponse.orderTypes', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='icebergAllowed', full_name='martin.FetchExchangeInfoSymbolResponse.icebergAllowed', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ocoAllowed', full_name='martin.FetchExchangeInfoSymbolResponse.ocoAllowed', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quoteOrderQtyMarketAllowed', full_name='martin.FetchExchangeInfoSymbolResponse.quoteOrderQtyMarketAllowed', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowTrailingStop', full_name='martin.FetchExchangeInfoSymbolResponse.allowTrailingStop', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isSpotTradingAllowed', full_name='martin.FetchExchangeInfoSymbolResponse.isSpotTradingAllowed', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isMarginTradingAllowed', full_name='martin.FetchExchangeInfoSymbolResponse.isMarginTradingAllowed', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='martin.FetchExchangeInfoSymbolResponse.filters', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permissions', full_name='martin.FetchExchangeInfoSymbolResponse.permissions', index=17,
      number=18, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3537,
  serialized_end=5946,
)


_CANCELALLORDERSRESPONSE_CANCELORDER = _descriptor.Descriptor(
  name='CancelOrder',
  full_name='martin.CancelAllOrdersResponse.CancelOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='martin.CancelAllOrdersResponse.CancelOrder.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origClientOrderId', full_name='martin.CancelAllOrdersResponse.CancelOrder.origClientOrderId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orderId', full_name='martin.CancelAllOrdersResponse.CancelOrder.orderId', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orderListId', full_name='martin.CancelAllOrdersResponse.CancelOrder.orderListId', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clientOrderId', full_name='martin.CancelAllOrdersResponse.CancelOrder.clientOrderId', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transactTime', full_name='martin.CancelAllOrdersResponse.CancelOrder.transactTime', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='martin.CancelAllOrdersResponse.CancelOrder.price', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origQty', full_name='martin.CancelAllOrdersResponse.CancelOrder.origQty', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='executedQty', full_name='martin.CancelAllOrdersResponse.CancelOrder.executedQty', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cummulativeQuoteQty', full_name='martin.CancelAllOrdersResponse.CancelOrder.cummulativeQuoteQty', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='martin.CancelAllOrdersResponse.CancelOrder.status', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeInForce', full_name='martin.CancelAllOrdersResponse.CancelOrder.timeInForce', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='martin.CancelAllOrdersResponse.CancelOrder.type', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='side', full_name='martin.CancelAllOrdersResponse.CancelOrder.side', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6037,
  serialized_end=6323,
)

_CANCELALLORDERSRESPONSE = _descriptor.Descriptor(
  name='CancelAllOrdersResponse',
  full_name='martin.CancelAllOrdersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='martin.CancelAllOrdersResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CANCELALLORDERSRESPONSE_CANCELORDER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5949,
  serialized_end=6323,
)


_FETCHORDERREQUEST = _descriptor.Descriptor(
  name='FetchOrderRequest',
  full_name='martin.FetchOrderRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='martin.FetchOrderRequest.client_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='martin.FetchOrderRequest.symbol', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_id', full_name='martin.FetchOrderRequest.order_id', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filled_update_call', full_name='martin.FetchOrderRequest.filled_update_call', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6325,
  serialized_end=6425,
)


_FETCHORDERRESPONSE = _descriptor.Descriptor(
  name='FetchOrderResponse',
  full_name='martin.FetchOrderResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='martin.FetchOrderResponse.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orderId', full_name='martin.FetchOrderResponse.orderId', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orderListId', full_name='martin.FetchOrderResponse.orderListId', index=2,
      number=3, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clientOrderId', full_name='martin.FetchOrderResponse.clientOrderId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='martin.FetchOrderResponse.price', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origQty', full_name='martin.FetchOrderResponse.origQty', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='executedQty', full_name='martin.FetchOrderResponse.executedQty', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cummulativeQuoteQty', full_name='martin.FetchOrderResponse.cummulativeQuoteQty', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='martin.FetchOrderResponse.status', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeInForce', full_name='martin.FetchOrderResponse.timeInForce', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='martin.FetchOrderResponse.type', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='side', full_name='martin.FetchOrderResponse.side', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stopPrice', full_name='martin.FetchOrderResponse.stopPrice', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='icebergQty', full_name='martin.FetchOrderResponse.icebergQty', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='martin.FetchOrderResponse.time', index=14,
      number=15, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateTime', full_name='martin.FetchOrderResponse.updateTime', index=15,
      number=16, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isWorking', full_name='martin.FetchOrderResponse.isWorking', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origQuoteOrderQty', full_name='martin.FetchOrderResponse.origQuoteOrderQty', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6428,
  serialized_end=6791,
)


_FETCHOPENORDERSRESPONSE_ORDER = _descriptor.Descriptor(
  name='Order',
  full_name='martin.FetchOpenOrdersResponse.Order',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='martin.FetchOpenOrdersResponse.Order.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orderId', full_name='martin.FetchOpenOrdersResponse.Order.orderId', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orderListId', full_name='martin.FetchOpenOrdersResponse.Order.orderListId', index=2,
      number=3, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clientOrderId', full_name='martin.FetchOpenOrdersResponse.Order.clientOrderId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='martin.FetchOpenOrdersResponse.Order.price', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origQty', full_name='martin.FetchOpenOrdersResponse.Order.origQty', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='executedQty', full_name='martin.FetchOpenOrdersResponse.Order.executedQty', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cummulativeQuoteQty', full_name='martin.FetchOpenOrdersResponse.Order.cummulativeQuoteQty', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='martin.FetchOpenOrdersResponse.Order.status', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeInForce', full_name='martin.FetchOpenOrdersResponse.Order.timeInForce', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='martin.FetchOpenOrdersResponse.Order.type', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='side', full_name='martin.FetchOpenOrdersResponse.Order.side', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stopPrice', full_name='martin.FetchOpenOrdersResponse.Order.stopPrice', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='icebergQty', full_name='martin.FetchOpenOrdersResponse.Order.icebergQty', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='martin.FetchOpenOrdersResponse.Order.time', index=14,
      number=15, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateTime', full_name='martin.FetchOpenOrdersResponse.Order.updateTime', index=15,
      number=16, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isWorking', full_name='martin.FetchOpenOrdersResponse.Order.isWorking', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origQuoteOrderQty', full_name='martin.FetchOpenOrdersResponse.Order.origQuoteOrderQty', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6898,
  serialized_end=7248,
)

_FETCHOPENORDERSRESPONSE = _descriptor.Descriptor(
  name='FetchOpenOrdersResponse',
  full_name='martin.FetchOpenOrdersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rate_limiter', full_name='martin.FetchOpenOrdersResponse.rate_limiter', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='martin.FetchOpenOrdersResponse.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FETCHOPENORDERSRESPONSE_ORDER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6794,
  serialized_end=7248,
)


_MARKETREQUEST = _descriptor.Descriptor(
  name='MarketRequest',
  full_name='martin.MarketRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='martin.MarketRequest.client_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='martin.MarketRequest.symbol', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7250,
  serialized_end=7300,
)


_STARTSTREAMREQUEST = _descriptor.Descriptor(
  name='StartStreamRequest',
  full_name='martin.StartStreamRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='martin.StartStreamRequest.client_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='martin.StartStreamRequest.symbol', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_stream_count', full_name='martin.StartStreamRequest.market_stream_count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_stream_count', full_name='martin.StartStreamRequest.user_stream_count', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7302,
  serialized_end=7413,
)


_OPENCLIENTCONNECTIONREQUEST = _descriptor.Descriptor(
  name='OpenClientConnectionRequest',
  full_name='martin.OpenClientConnectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_name', full_name='martin.OpenClientConnectionRequest.account_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rate_limiter', full_name='martin.OpenClientConnectionRequest.rate_limiter', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7415,
  serialized_end=7488,
)


_OPENCLIENTCONNECTIONID = _descriptor.Descriptor(
  name='OpenClientConnectionId',
  full_name='martin.OpenClientConnectionId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='martin.OpenClientConnectionId.client_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='srv_version', full_name='martin.OpenClientConnectionId.srv_version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rate_limiter', full_name='martin.OpenClientConnectionId.rate_limiter', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7490,
  serialized_end=7576,
)


_FETCHSERVERTIMEREQUEST = _descriptor.Descriptor(
  name='FetchServerTimeRequest',
  full_name='martin.FetchServerTimeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='martin.FetchServerTimeRequest.client_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7578,
  serialized_end=7621,
)


_FETCHSERVERTIMERESPONSE = _descriptor.Descriptor(
  name='FetchServerTimeResponse',
  full_name='martin.FetchServerTimeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_time', full_name='martin.FetchServerTimeResponse.server_time', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7623,
  serialized_end=7669,
)

_FETCHFUNDINGWALLETRESPONSE_BALANCES.containing_type = _FETCHFUNDINGWALLETRESPONSE
_FETCHFUNDINGWALLETRESPONSE.fields_by_name['balances'].message_type = _FETCHFUNDINGWALLETRESPONSE_BALANCES
_ACCOUNTTRADELISTRESPONSE_TRADE.containing_type = _ACCOUNTTRADELISTRESPONSE
_ACCOUNTTRADELISTRESPONSE.fields_by_name['items'].message_type = _ACCOUNTTRADELISTRESPONSE_TRADE
_FETCHACCOUNTBALANCERESPONSE_BALANCES.containing_type = _FETCHACCOUNTBALANCERESPONSE
_FETCHACCOUNTBALANCERESPONSE.fields_by_name['balances'].message_type = _FETCHACCOUNTBALANCERESPONSE_BALANCES
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_PRICEFILTER.containing_type = _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_PERCENTPRICE.containing_type = _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_LOTSIZE.containing_type = _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_MINNOTIONAL.containing_type = _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_ICEBERGPARTS.containing_type = _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_MARKETLOTSIZE.containing_type = _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_MAXNUMORDERS.containing_type = _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_MAXNUMALGOORDERS.containing_type = _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_MAXNUMICEBERGORDERS.containing_type = _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_MAXPOSITION.containing_type = _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.fields_by_name['price_filter'].message_type = _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_PRICEFILTER
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.fields_by_name['percent_price'].message_type = _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_PERCENTPRICE
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.fields_by_name['lot_size'].message_type = _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_LOTSIZE
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.fields_by_name['min_notional'].message_type = _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_MINNOTIONAL
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.fields_by_name['iceberg_parts'].message_type = _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_ICEBERGPARTS
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.fields_by_name['market_lot_size'].message_type = _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_MARKETLOTSIZE
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.fields_by_name['max_num_orders'].message_type = _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_MAXNUMORDERS
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.fields_by_name['max_num_algo_orders'].message_type = _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_MAXNUMALGOORDERS
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.fields_by_name['max_num_iceberg_orders'].message_type = _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_MAXNUMICEBERGORDERS
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.fields_by_name['max_position'].message_type = _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_MAXPOSITION
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.containing_type = _FETCHEXCHANGEINFOSYMBOLRESPONSE
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.oneofs_by_name['_price_filter'].fields.append(
  _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.fields_by_name['price_filter'])
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.fields_by_name['price_filter'].containing_oneof = _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.oneofs_by_name['_price_filter']
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.oneofs_by_name['_percent_price'].fields.append(
  _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.fields_by_name['percent_price'])
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.fields_by_name['percent_price'].containing_oneof = _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.oneofs_by_name['_percent_price']
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.oneofs_by_name['_lot_size'].fields.append(
  _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.fields_by_name['lot_size'])
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.fields_by_name['lot_size'].containing_oneof = _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.oneofs_by_name['_lot_size']
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.oneofs_by_name['_min_notional'].fields.append(
  _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.fields_by_name['min_notional'])
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.fields_by_name['min_notional'].containing_oneof = _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.oneofs_by_name['_min_notional']
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.oneofs_by_name['_iceberg_parts'].fields.append(
  _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.fields_by_name['iceberg_parts'])
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.fields_by_name['iceberg_parts'].containing_oneof = _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.oneofs_by_name['_iceberg_parts']
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.oneofs_by_name['_market_lot_size'].fields.append(
  _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.fields_by_name['market_lot_size'])
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.fields_by_name['market_lot_size'].containing_oneof = _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.oneofs_by_name['_market_lot_size']
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.oneofs_by_name['_max_num_orders'].fields.append(
  _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.fields_by_name['max_num_orders'])
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.fields_by_name['max_num_orders'].containing_oneof = _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.oneofs_by_name['_max_num_orders']
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.oneofs_by_name['_max_num_algo_orders'].fields.append(
  _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.fields_by_name['max_num_algo_orders'])
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.fields_by_name['max_num_algo_orders'].containing_oneof = _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.oneofs_by_name['_max_num_algo_orders']
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.oneofs_by_name['_max_num_iceberg_orders'].fields.append(
  _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.fields_by_name['max_num_iceberg_orders'])
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.fields_by_name['max_num_iceberg_orders'].containing_oneof = _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.oneofs_by_name['_max_num_iceberg_orders']
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.oneofs_by_name['_max_position'].fields.append(
  _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.fields_by_name['max_position'])
_FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.fields_by_name['max_position'].containing_oneof = _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS.oneofs_by_name['_max_position']
_FETCHEXCHANGEINFOSYMBOLRESPONSE.fields_by_name['filters'].message_type = _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS
_CANCELALLORDERSRESPONSE_CANCELORDER.containing_type = _CANCELALLORDERSRESPONSE
_CANCELALLORDERSRESPONSE.fields_by_name['items'].message_type = _CANCELALLORDERSRESPONSE_CANCELORDER
_FETCHOPENORDERSRESPONSE_ORDER.containing_type = _FETCHOPENORDERSRESPONSE
_FETCHOPENORDERSRESPONSE.fields_by_name['items'].message_type = _FETCHOPENORDERSRESPONSE_ORDER
DESCRIPTOR.message_types_by_name['FetchFundingWalletRequest'] = _FETCHFUNDINGWALLETREQUEST
DESCRIPTOR.message_types_by_name['FetchFundingWalletResponse'] = _FETCHFUNDINGWALLETRESPONSE
DESCRIPTOR.message_types_by_name['CancelOrderResponse'] = _CANCELORDERRESPONSE
DESCRIPTOR.message_types_by_name['CancelOrderRequest'] = _CANCELORDERREQUEST
DESCRIPTOR.message_types_by_name['CreateLimitOrderResponse'] = _CREATELIMITORDERRESPONSE
DESCRIPTOR.message_types_by_name['CreateLimitOrderRequest'] = _CREATELIMITORDERREQUEST
DESCRIPTOR.message_types_by_name['OnOrderUpdateResponse'] = _ONORDERUPDATERESPONSE
DESCRIPTOR.message_types_by_name['OnFundsUpdateResponse'] = _ONFUNDSUPDATERESPONSE
DESCRIPTOR.message_types_by_name['OnFundsUpdateRequest'] = _ONFUNDSUPDATEREQUEST
DESCRIPTOR.message_types_by_name['SimpleResponse'] = _SIMPLERESPONSE
DESCRIPTOR.message_types_by_name['OnTickerUpdateResponse'] = _ONTICKERUPDATERESPONSE
DESCRIPTOR.message_types_by_name['AccountTradeListResponse'] = _ACCOUNTTRADELISTRESPONSE
DESCRIPTOR.message_types_by_name['AccountTradeListRequest'] = _ACCOUNTTRADELISTREQUEST
DESCRIPTOR.message_types_by_name['FetchKlinesResponse'] = _FETCHKLINESRESPONSE
DESCRIPTOR.message_types_by_name['OnKlinesUpdateResponse'] = _ONKLINESUPDATERESPONSE
DESCRIPTOR.message_types_by_name['FetchKlinesRequest'] = _FETCHKLINESREQUEST
DESCRIPTOR.message_types_by_name['FetchTickerPriceChangeStatisticsResponse'] = _FETCHTICKERPRICECHANGESTATISTICSRESPONSE
DESCRIPTOR.message_types_by_name['FetchSymbolPriceTickerResponse'] = _FETCHSYMBOLPRICETICKERRESPONSE
DESCRIPTOR.message_types_by_name['FetchOrderBookResponse'] = _FETCHORDERBOOKRESPONSE
DESCRIPTOR.message_types_by_name['FetchAccountBalanceResponse'] = _FETCHACCOUNTBALANCERESPONSE
DESCRIPTOR.message_types_by_name['FetchExchangeInfoSymbolResponse'] = _FETCHEXCHANGEINFOSYMBOLRESPONSE
DESCRIPTOR.message_types_by_name['CancelAllOrdersResponse'] = _CANCELALLORDERSRESPONSE
DESCRIPTOR.message_types_by_name['FetchOrderRequest'] = _FETCHORDERREQUEST
DESCRIPTOR.message_types_by_name['FetchOrderResponse'] = _FETCHORDERRESPONSE
DESCRIPTOR.message_types_by_name['FetchOpenOrdersResponse'] = _FETCHOPENORDERSRESPONSE
DESCRIPTOR.message_types_by_name['MarketRequest'] = _MARKETREQUEST
DESCRIPTOR.message_types_by_name['StartStreamRequest'] = _STARTSTREAMREQUEST
DESCRIPTOR.message_types_by_name['OpenClientConnectionRequest'] = _OPENCLIENTCONNECTIONREQUEST
DESCRIPTOR.message_types_by_name['OpenClientConnectionId'] = _OPENCLIENTCONNECTIONID
DESCRIPTOR.message_types_by_name['FetchServerTimeRequest'] = _FETCHSERVERTIMEREQUEST
DESCRIPTOR.message_types_by_name['FetchServerTimeResponse'] = _FETCHSERVERTIMERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FetchFundingWalletRequest = _reflection.GeneratedProtocolMessageType('FetchFundingWalletRequest', (_message.Message,), {
  'DESCRIPTOR' : _FETCHFUNDINGWALLETREQUEST,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:martin.FetchFundingWalletRequest)
  })
_sym_db.RegisterMessage(FetchFundingWalletRequest)

FetchFundingWalletResponse = _reflection.GeneratedProtocolMessageType('FetchFundingWalletResponse', (_message.Message,), {

  'Balances' : _reflection.GeneratedProtocolMessageType('Balances', (_message.Message,), {
    'DESCRIPTOR' : _FETCHFUNDINGWALLETRESPONSE_BALANCES,
    '__module__' : 'api_pb2'
    # @@protoc_insertion_point(class_scope:martin.FetchFundingWalletResponse.Balances)
    })
  ,
  'DESCRIPTOR' : _FETCHFUNDINGWALLETRESPONSE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:martin.FetchFundingWalletResponse)
  })
_sym_db.RegisterMessage(FetchFundingWalletResponse)
_sym_db.RegisterMessage(FetchFundingWalletResponse.Balances)

CancelOrderResponse = _reflection.GeneratedProtocolMessageType('CancelOrderResponse', (_message.Message,), {
  'DESCRIPTOR' : _CANCELORDERRESPONSE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:martin.CancelOrderResponse)
  })
_sym_db.RegisterMessage(CancelOrderResponse)

CancelOrderRequest = _reflection.GeneratedProtocolMessageType('CancelOrderRequest', (_message.Message,), {
  'DESCRIPTOR' : _CANCELORDERREQUEST,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:martin.CancelOrderRequest)
  })
_sym_db.RegisterMessage(CancelOrderRequest)

CreateLimitOrderResponse = _reflection.GeneratedProtocolMessageType('CreateLimitOrderResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATELIMITORDERRESPONSE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:martin.CreateLimitOrderResponse)
  })
_sym_db.RegisterMessage(CreateLimitOrderResponse)

CreateLimitOrderRequest = _reflection.GeneratedProtocolMessageType('CreateLimitOrderRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATELIMITORDERREQUEST,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:martin.CreateLimitOrderRequest)
  })
_sym_db.RegisterMessage(CreateLimitOrderRequest)

OnOrderUpdateResponse = _reflection.GeneratedProtocolMessageType('OnOrderUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _ONORDERUPDATERESPONSE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:martin.OnOrderUpdateResponse)
  })
_sym_db.RegisterMessage(OnOrderUpdateResponse)

OnFundsUpdateResponse = _reflection.GeneratedProtocolMessageType('OnFundsUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _ONFUNDSUPDATERESPONSE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:martin.OnFundsUpdateResponse)
  })
_sym_db.RegisterMessage(OnFundsUpdateResponse)

OnFundsUpdateRequest = _reflection.GeneratedProtocolMessageType('OnFundsUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _ONFUNDSUPDATEREQUEST,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:martin.OnFundsUpdateRequest)
  })
_sym_db.RegisterMessage(OnFundsUpdateRequest)

SimpleResponse = _reflection.GeneratedProtocolMessageType('SimpleResponse', (_message.Message,), {
  'DESCRIPTOR' : _SIMPLERESPONSE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:martin.SimpleResponse)
  })
_sym_db.RegisterMessage(SimpleResponse)

OnTickerUpdateResponse = _reflection.GeneratedProtocolMessageType('OnTickerUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _ONTICKERUPDATERESPONSE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:martin.OnTickerUpdateResponse)
  })
_sym_db.RegisterMessage(OnTickerUpdateResponse)

AccountTradeListResponse = _reflection.GeneratedProtocolMessageType('AccountTradeListResponse', (_message.Message,), {

  'Trade' : _reflection.GeneratedProtocolMessageType('Trade', (_message.Message,), {
    'DESCRIPTOR' : _ACCOUNTTRADELISTRESPONSE_TRADE,
    '__module__' : 'api_pb2'
    # @@protoc_insertion_point(class_scope:martin.AccountTradeListResponse.Trade)
    })
  ,
  'DESCRIPTOR' : _ACCOUNTTRADELISTRESPONSE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:martin.AccountTradeListResponse)
  })
_sym_db.RegisterMessage(AccountTradeListResponse)
_sym_db.RegisterMessage(AccountTradeListResponse.Trade)

AccountTradeListRequest = _reflection.GeneratedProtocolMessageType('AccountTradeListRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTTRADELISTREQUEST,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:martin.AccountTradeListRequest)
  })
_sym_db.RegisterMessage(AccountTradeListRequest)

FetchKlinesResponse = _reflection.GeneratedProtocolMessageType('FetchKlinesResponse', (_message.Message,), {
  'DESCRIPTOR' : _FETCHKLINESRESPONSE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:martin.FetchKlinesResponse)
  })
_sym_db.RegisterMessage(FetchKlinesResponse)

OnKlinesUpdateResponse = _reflection.GeneratedProtocolMessageType('OnKlinesUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _ONKLINESUPDATERESPONSE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:martin.OnKlinesUpdateResponse)
  })
_sym_db.RegisterMessage(OnKlinesUpdateResponse)

FetchKlinesRequest = _reflection.GeneratedProtocolMessageType('FetchKlinesRequest', (_message.Message,), {
  'DESCRIPTOR' : _FETCHKLINESREQUEST,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:martin.FetchKlinesRequest)
  })
_sym_db.RegisterMessage(FetchKlinesRequest)

FetchTickerPriceChangeStatisticsResponse = _reflection.GeneratedProtocolMessageType('FetchTickerPriceChangeStatisticsResponse', (_message.Message,), {
  'DESCRIPTOR' : _FETCHTICKERPRICECHANGESTATISTICSRESPONSE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:martin.FetchTickerPriceChangeStatisticsResponse)
  })
_sym_db.RegisterMessage(FetchTickerPriceChangeStatisticsResponse)

FetchSymbolPriceTickerResponse = _reflection.GeneratedProtocolMessageType('FetchSymbolPriceTickerResponse', (_message.Message,), {
  'DESCRIPTOR' : _FETCHSYMBOLPRICETICKERRESPONSE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:martin.FetchSymbolPriceTickerResponse)
  })
_sym_db.RegisterMessage(FetchSymbolPriceTickerResponse)

FetchOrderBookResponse = _reflection.GeneratedProtocolMessageType('FetchOrderBookResponse', (_message.Message,), {
  'DESCRIPTOR' : _FETCHORDERBOOKRESPONSE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:martin.FetchOrderBookResponse)
  })
_sym_db.RegisterMessage(FetchOrderBookResponse)

FetchAccountBalanceResponse = _reflection.GeneratedProtocolMessageType('FetchAccountBalanceResponse', (_message.Message,), {

  'Balances' : _reflection.GeneratedProtocolMessageType('Balances', (_message.Message,), {
    'DESCRIPTOR' : _FETCHACCOUNTBALANCERESPONSE_BALANCES,
    '__module__' : 'api_pb2'
    # @@protoc_insertion_point(class_scope:martin.FetchAccountBalanceResponse.Balances)
    })
  ,
  'DESCRIPTOR' : _FETCHACCOUNTBALANCERESPONSE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:martin.FetchAccountBalanceResponse)
  })
_sym_db.RegisterMessage(FetchAccountBalanceResponse)
_sym_db.RegisterMessage(FetchAccountBalanceResponse.Balances)

FetchExchangeInfoSymbolResponse = _reflection.GeneratedProtocolMessageType('FetchExchangeInfoSymbolResponse', (_message.Message,), {

  'Filters' : _reflection.GeneratedProtocolMessageType('Filters', (_message.Message,), {

    'PriceFilter' : _reflection.GeneratedProtocolMessageType('PriceFilter', (_message.Message,), {
      'DESCRIPTOR' : _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_PRICEFILTER,
      '__module__' : 'api_pb2'
      # @@protoc_insertion_point(class_scope:martin.FetchExchangeInfoSymbolResponse.Filters.PriceFilter)
      })
    ,

    'PercentPrice' : _reflection.GeneratedProtocolMessageType('PercentPrice', (_message.Message,), {
      'DESCRIPTOR' : _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_PERCENTPRICE,
      '__module__' : 'api_pb2'
      # @@protoc_insertion_point(class_scope:martin.FetchExchangeInfoSymbolResponse.Filters.PercentPrice)
      })
    ,

    'LotSize' : _reflection.GeneratedProtocolMessageType('LotSize', (_message.Message,), {
      'DESCRIPTOR' : _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_LOTSIZE,
      '__module__' : 'api_pb2'
      # @@protoc_insertion_point(class_scope:martin.FetchExchangeInfoSymbolResponse.Filters.LotSize)
      })
    ,

    'MinNotional' : _reflection.GeneratedProtocolMessageType('MinNotional', (_message.Message,), {
      'DESCRIPTOR' : _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_MINNOTIONAL,
      '__module__' : 'api_pb2'
      # @@protoc_insertion_point(class_scope:martin.FetchExchangeInfoSymbolResponse.Filters.MinNotional)
      })
    ,

    'IcebergParts' : _reflection.GeneratedProtocolMessageType('IcebergParts', (_message.Message,), {
      'DESCRIPTOR' : _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_ICEBERGPARTS,
      '__module__' : 'api_pb2'
      # @@protoc_insertion_point(class_scope:martin.FetchExchangeInfoSymbolResponse.Filters.IcebergParts)
      })
    ,

    'MarketLotSize' : _reflection.GeneratedProtocolMessageType('MarketLotSize', (_message.Message,), {
      'DESCRIPTOR' : _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_MARKETLOTSIZE,
      '__module__' : 'api_pb2'
      # @@protoc_insertion_point(class_scope:martin.FetchExchangeInfoSymbolResponse.Filters.MarketLotSize)
      })
    ,

    'MaxNumOrders' : _reflection.GeneratedProtocolMessageType('MaxNumOrders', (_message.Message,), {
      'DESCRIPTOR' : _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_MAXNUMORDERS,
      '__module__' : 'api_pb2'
      # @@protoc_insertion_point(class_scope:martin.FetchExchangeInfoSymbolResponse.Filters.MaxNumOrders)
      })
    ,

    'MaxNumAlgoOrders' : _reflection.GeneratedProtocolMessageType('MaxNumAlgoOrders', (_message.Message,), {
      'DESCRIPTOR' : _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_MAXNUMALGOORDERS,
      '__module__' : 'api_pb2'
      # @@protoc_insertion_point(class_scope:martin.FetchExchangeInfoSymbolResponse.Filters.MaxNumAlgoOrders)
      })
    ,

    'MaxNumIcebergOrders' : _reflection.GeneratedProtocolMessageType('MaxNumIcebergOrders', (_message.Message,), {
      'DESCRIPTOR' : _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_MAXNUMICEBERGORDERS,
      '__module__' : 'api_pb2'
      # @@protoc_insertion_point(class_scope:martin.FetchExchangeInfoSymbolResponse.Filters.MaxNumIcebergOrders)
      })
    ,

    'MaxPosition' : _reflection.GeneratedProtocolMessageType('MaxPosition', (_message.Message,), {
      'DESCRIPTOR' : _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS_MAXPOSITION,
      '__module__' : 'api_pb2'
      # @@protoc_insertion_point(class_scope:martin.FetchExchangeInfoSymbolResponse.Filters.MaxPosition)
      })
    ,
    'DESCRIPTOR' : _FETCHEXCHANGEINFOSYMBOLRESPONSE_FILTERS,
    '__module__' : 'api_pb2'
    # @@protoc_insertion_point(class_scope:martin.FetchExchangeInfoSymbolResponse.Filters)
    })
  ,
  'DESCRIPTOR' : _FETCHEXCHANGEINFOSYMBOLRESPONSE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:martin.FetchExchangeInfoSymbolResponse)
  })
_sym_db.RegisterMessage(FetchExchangeInfoSymbolResponse)
_sym_db.RegisterMessage(FetchExchangeInfoSymbolResponse.Filters)
_sym_db.RegisterMessage(FetchExchangeInfoSymbolResponse.Filters.PriceFilter)
_sym_db.RegisterMessage(FetchExchangeInfoSymbolResponse.Filters.PercentPrice)
_sym_db.RegisterMessage(FetchExchangeInfoSymbolResponse.Filters.LotSize)
_sym_db.RegisterMessage(FetchExchangeInfoSymbolResponse.Filters.MinNotional)
_sym_db.RegisterMessage(FetchExchangeInfoSymbolResponse.Filters.IcebergParts)
_sym_db.RegisterMessage(FetchExchangeInfoSymbolResponse.Filters.MarketLotSize)
_sym_db.RegisterMessage(FetchExchangeInfoSymbolResponse.Filters.MaxNumOrders)
_sym_db.RegisterMessage(FetchExchangeInfoSymbolResponse.Filters.MaxNumAlgoOrders)
_sym_db.RegisterMessage(FetchExchangeInfoSymbolResponse.Filters.MaxNumIcebergOrders)
_sym_db.RegisterMessage(FetchExchangeInfoSymbolResponse.Filters.MaxPosition)

CancelAllOrdersResponse = _reflection.GeneratedProtocolMessageType('CancelAllOrdersResponse', (_message.Message,), {

  'CancelOrder' : _reflection.GeneratedProtocolMessageType('CancelOrder', (_message.Message,), {
    'DESCRIPTOR' : _CANCELALLORDERSRESPONSE_CANCELORDER,
    '__module__' : 'api_pb2'
    # @@protoc_insertion_point(class_scope:martin.CancelAllOrdersResponse.CancelOrder)
    })
  ,
  'DESCRIPTOR' : _CANCELALLORDERSRESPONSE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:martin.CancelAllOrdersResponse)
  })
_sym_db.RegisterMessage(CancelAllOrdersResponse)
_sym_db.RegisterMessage(CancelAllOrdersResponse.CancelOrder)

FetchOrderRequest = _reflection.GeneratedProtocolMessageType('FetchOrderRequest', (_message.Message,), {
  'DESCRIPTOR' : _FETCHORDERREQUEST,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:martin.FetchOrderRequest)
  })
_sym_db.RegisterMessage(FetchOrderRequest)

FetchOrderResponse = _reflection.GeneratedProtocolMessageType('FetchOrderResponse', (_message.Message,), {
  'DESCRIPTOR' : _FETCHORDERRESPONSE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:martin.FetchOrderResponse)
  })
_sym_db.RegisterMessage(FetchOrderResponse)

FetchOpenOrdersResponse = _reflection.GeneratedProtocolMessageType('FetchOpenOrdersResponse', (_message.Message,), {

  'Order' : _reflection.GeneratedProtocolMessageType('Order', (_message.Message,), {
    'DESCRIPTOR' : _FETCHOPENORDERSRESPONSE_ORDER,
    '__module__' : 'api_pb2'
    # @@protoc_insertion_point(class_scope:martin.FetchOpenOrdersResponse.Order)
    })
  ,
  'DESCRIPTOR' : _FETCHOPENORDERSRESPONSE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:martin.FetchOpenOrdersResponse)
  })
_sym_db.RegisterMessage(FetchOpenOrdersResponse)
_sym_db.RegisterMessage(FetchOpenOrdersResponse.Order)

MarketRequest = _reflection.GeneratedProtocolMessageType('MarketRequest', (_message.Message,), {
  'DESCRIPTOR' : _MARKETREQUEST,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:martin.MarketRequest)
  })
_sym_db.RegisterMessage(MarketRequest)

StartStreamRequest = _reflection.GeneratedProtocolMessageType('StartStreamRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTSTREAMREQUEST,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:martin.StartStreamRequest)
  })
_sym_db.RegisterMessage(StartStreamRequest)

OpenClientConnectionRequest = _reflection.GeneratedProtocolMessageType('OpenClientConnectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _OPENCLIENTCONNECTIONREQUEST,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:martin.OpenClientConnectionRequest)
  })
_sym_db.RegisterMessage(OpenClientConnectionRequest)

OpenClientConnectionId = _reflection.GeneratedProtocolMessageType('OpenClientConnectionId', (_message.Message,), {
  'DESCRIPTOR' : _OPENCLIENTCONNECTIONID,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:martin.OpenClientConnectionId)
  })
_sym_db.RegisterMessage(OpenClientConnectionId)

FetchServerTimeRequest = _reflection.GeneratedProtocolMessageType('FetchServerTimeRequest', (_message.Message,), {
  'DESCRIPTOR' : _FETCHSERVERTIMEREQUEST,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:martin.FetchServerTimeRequest)
  })
_sym_db.RegisterMessage(FetchServerTimeRequest)

FetchServerTimeResponse = _reflection.GeneratedProtocolMessageType('FetchServerTimeResponse', (_message.Message,), {
  'DESCRIPTOR' : _FETCHSERVERTIMERESPONSE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:martin.FetchServerTimeResponse)
  })
_sym_db.RegisterMessage(FetchServerTimeResponse)



_MARTIN = _descriptor.ServiceDescriptor(
  name='Martin',
  full_name='martin.Martin',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=7672,
  serialized_end=9584,
  methods=[
  _descriptor.MethodDescriptor(
    name='OpenClientConnection',
    full_name='martin.Martin.OpenClientConnection',
    index=0,
    containing_service=None,
    input_type=_OPENCLIENTCONNECTIONREQUEST,
    output_type=_OPENCLIENTCONNECTIONID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FetchServerTime',
    full_name='martin.Martin.FetchServerTime',
    index=1,
    containing_service=None,
    input_type=_OPENCLIENTCONNECTIONID,
    output_type=_FETCHSERVERTIMERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FetchOpenOrders',
    full_name='martin.Martin.FetchOpenOrders',
    index=2,
    containing_service=None,
    input_type=_MARKETREQUEST,
    output_type=_FETCHOPENORDERSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CancelAllOrders',
    full_name='martin.Martin.CancelAllOrders',
    index=3,
    containing_service=None,
    input_type=_MARKETREQUEST,
    output_type=_FETCHOPENORDERSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FetchExchangeInfoSymbol',
    full_name='martin.Martin.FetchExchangeInfoSymbol',
    index=4,
    containing_service=None,
    input_type=_MARKETREQUEST,
    output_type=_FETCHEXCHANGEINFOSYMBOLRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FetchAccountInformation',
    full_name='martin.Martin.FetchAccountInformation',
    index=5,
    containing_service=None,
    input_type=_OPENCLIENTCONNECTIONID,
    output_type=_FETCHACCOUNTBALANCERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FetchOrderBook',
    full_name='martin.Martin.FetchOrderBook',
    index=6,
    containing_service=None,
    input_type=_MARKETREQUEST,
    output_type=_FETCHORDERBOOKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FetchSymbolPriceTicker',
    full_name='martin.Martin.FetchSymbolPriceTicker',
    index=7,
    containing_service=None,
    input_type=_MARKETREQUEST,
    output_type=_FETCHSYMBOLPRICETICKERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FetchTickerPriceChangeStatistics',
    full_name='martin.Martin.FetchTickerPriceChangeStatistics',
    index=8,
    containing_service=None,
    input_type=_MARKETREQUEST,
    output_type=_FETCHTICKERPRICECHANGESTATISTICSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FetchKlines',
    full_name='martin.Martin.FetchKlines',
    index=9,
    containing_service=None,
    input_type=_FETCHKLINESREQUEST,
    output_type=_FETCHKLINESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FetchAccountTradeList',
    full_name='martin.Martin.FetchAccountTradeList',
    index=10,
    containing_service=None,
    input_type=_ACCOUNTTRADELISTREQUEST,
    output_type=_ACCOUNTTRADELISTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnTickerUpdate',
    full_name='martin.Martin.OnTickerUpdate',
    index=11,
    containing_service=None,
    input_type=_MARKETREQUEST,
    output_type=_ONTICKERUPDATERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnOrderBookUpdate',
    full_name='martin.Martin.OnOrderBookUpdate',
    index=12,
    containing_service=None,
    input_type=_MARKETREQUEST,
    output_type=_FETCHORDERBOOKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StopStream',
    full_name='martin.Martin.StopStream',
    index=13,
    containing_service=None,
    input_type=_MARKETREQUEST,
    output_type=_SIMPLERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StartStream',
    full_name='martin.Martin.StartStream',
    index=14,
    containing_service=None,
    input_type=_STARTSTREAMREQUEST,
    output_type=_SIMPLERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnFundsUpdate',
    full_name='martin.Martin.OnFundsUpdate',
    index=15,
    containing_service=None,
    input_type=_ONFUNDSUPDATEREQUEST,
    output_type=_ONFUNDSUPDATERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnOrderUpdate',
    full_name='martin.Martin.OnOrderUpdate',
    index=16,
    containing_service=None,
    input_type=_MARKETREQUEST,
    output_type=_ONORDERUPDATERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateLimitOrder',
    full_name='martin.Martin.CreateLimitOrder',
    index=17,
    containing_service=None,
    input_type=_CREATELIMITORDERREQUEST,
    output_type=_CREATELIMITORDERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CancelOrder',
    full_name='martin.Martin.CancelOrder',
    index=18,
    containing_service=None,
    input_type=_CANCELORDERREQUEST,
    output_type=_CANCELORDERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FetchOrder',
    full_name='martin.Martin.FetchOrder',
    index=19,
    containing_service=None,
    input_type=_FETCHORDERREQUEST,
    output_type=_FETCHORDERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ResetRateLimit',
    full_name='martin.Martin.ResetRateLimit',
    index=20,
    containing_service=None,
    input_type=_OPENCLIENTCONNECTIONID,
    output_type=_SIMPLERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnKlinesUpdate',
    full_name='martin.Martin.OnKlinesUpdate',
    index=21,
    containing_service=None,
    input_type=_FETCHKLINESREQUEST,
    output_type=_ONKLINESUPDATERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FetchFundingWallet',
    full_name='martin.Martin.FetchFundingWallet',
    index=22,
    containing_service=None,
    input_type=_FETCHFUNDINGWALLETREQUEST,
    output_type=_FETCHFUNDINGWALLETRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MARTIN)

DESCRIPTOR.services_by_name['Martin'] = _MARTIN

# @@protoc_insertion_point(module_scope)
